function probList = BPDNgen(varargin)
%BPDNGEN  Generates list of BPDN problems to run
%
%   PROBLIST = BPDNGEN(OPTIONS), all OPTIONS are optional and
%   have default values. OPTIONS consist of a keyword followed by a
%   value:
%
%   'path'   - ['data'] directory to store results in
%   'prefix' - ['BPDNtmp'] prefix of filename
%
%   PROBLIST is a cell array of cells. The entries per problem are
%   {solver, relative residual, problem name, filename}.
%
%   Examples:
%   plist = BPDNgen();              % Generate default list
%   plist = BPDNgen('path','data'); % Store results in 'data' dir
%
%Paper: Probing the Pareto Frontier for Basis Pursuit Solutions

%   Copyright 2008, Ewout van den Berg and Michael P. Friedlander
%   $Id$

% ---------------------------------------------------------------

% Parse parameters
[opts,varg] = parseOptions(varargin,{},{'path','prefix'});
path        = getOption(opts,'path','data');
prefix      = getOption(opts,'prefix','BPDNtmp');

solvers     = {'spgl1', 'sparselab', 'l1magic'};
relres      = [1e-1, 1e-2, 1e-3];
sparcoProbs = {'blocksig','cosspike','gcosspike','p3poly','sgnspike',...
               'blkheavi','blknheavi','srcsep1','srcsep2','srcsep3',...
               'soccer1','yinyang','blurrycam','blurspike','finger',...
               'seismic','jitter','spiketrn'};

probList = {}; i = 1;
for s = solvers
    for r = relres
        for p = sparcoProbs
            fn = sprintf('%s%s%s%03d.mat',path,filesep,prefix,i);
            probList{i} = {s{:},r,p{:},fn};
            i = i + 1;
        end
    end
end
