function probList = BPgen(varargin)
%BPGEN  Generates list of BP problems to run
%
%   PROBLIST = BPGEN(OPTIONS), all OPTIONS are optional and have
%   default values. OPTIONS consist of a keyword followed by a
%   value:
%
%   'path'   - ['data'] directory to store results in
%   'prefix' - ['BPtmp'] prefix of filename
%
%   PROBLIST is a cell array of cells. The entries per problem are
%   {solver, problem name, filename}.
%
%   Examples:
%   plist = BPgen();              % Generate default list
%   plist = BPgen('path','data'); % Store results in 'data' dir
%
%Paper: Probing the Pareto Frontier for Basis Pursuit Solutions

%   Copyright 2008, Ewout van den Berg and Michael P. Friedlander
%   $Id$

% ---------------------------------------------------------------

% Parse parameters
[opts,varg] = parseOptions(varargin,{},{'path','prefix'});
path        = getOption(opts,'path','data');
prefix      = getOption(opts,'prefix','BPtmp');

solvers     = {'spgl1', 'sparselab', 'pdco','l1magic','spgl1-2'};
sparcoProbs = {'blocksig','cosspike','gcosspike','p3poly','sgnspike',...
               'srcsep1','srcsep2','srcsep3','soccer1','yinyang', ...
               'blurrycam','blurspike','finger', 'seismic', ...
               'jitter','spiketrn'}; 
 
probList = {}; i = 1;
for s = solvers
     for p = sparcoProbs
         fn = sprintf('%s%s%s%03d.mat',path,filesep,prefix,i);
         probList{i} = {s{:},p{:},fn};
         i = i + 1;
     end
end
