function stats = PARETOrun(A,b,tau)
%PARETORUN  Solves a Lasso(tau) problem
%
%   STATS = TAUBPRUN(A,B,TAU) accurately solves the Lasso(tau)
%   problem given by matrix A, vector B and parameter TAU.
%
%Paper: Probing the Pareto Frontier for Basis Pursuit Solutions

%   Copyright 2008, Ewout van den Berg and Michael P. Friedlander
%   $Id$


% Check complexity of problem
infoA      = A([],0);
iscomplex  = (infoA{3}(1) == 1) || ...
             (infoA{3}(3) == 1) || ...
             (~isreal(b));

% Set parameters for SPGL1
opts = spgSetParms('iterations',20000, ...
                   'optTol',    1e-6, ...
                   'bpTol',     1e-8, ...
                   'verbosity', 0, ...
                   'iscomplex', iscomplex);

% Run SPGL1
[x,r,g,info] = spgl1(A,b,tau,[],[],opts);

% Set results
stats = struct();
stats.tau     = tau;
stats.xNorm   = norm(x,1);
stats.rNorm   = norm(r,2);
stats.rGap    = info.rGap;
stats.stat    = info.stat;
stats.lambda  = info.gNorm;

% Negate rNorm if solution is not optimal
if info.stat ~= 5
   stats.rNorm = -1 * stats.rNorm;
end

end % PARETOrun
