function stats = ParallelBatch(problems,funptr)
%ParallelBatch  Runs a batch of problems using parfor
%
%   STATS = PARALLELBATCH(PROBLEMS,FUNPRT), applies FUNPTR to all
%   problems in PROBLEMS and stores the results in STATS. Execution
%   is done using the parfor command to take advantage of parallel
%   computation. Prior to the parfor loop the problems are shuffled
%   for better load balance. After the loop the results are
%   unshuffled.
%
%Paper: Probing the Pareto Frontier for Basis Pursuit Solutions

%   Copyright 2008, Ewout van den Berg and Michael P. Friedlander
%   $Id$

% Initialize result
n     = length(probList);
stats = cell(1,n);

shuffle  = randperm(n);
problems = problems(shuffle);

parfor (i = 1:n)
    p = problems{i};
    stats{i} = funptr(p);
end

unshuffle(shuffle) = 1:n;
stats = stats(unshuffle);

end
