function [probList,solvers,fileList] = QPLSgen(problem,varargin)
%PARETOGEN  Generates list of QPLS problems to run
%
%   [PROBLIST,SOLVERS,FILELIST] = QPLSGEN(PROBLEM,OPTIONS)
%

%Paper: Probing the Pareto Frontier for Basis Pursuit Solutions

%   Copyright 2008, Ewout van den Berg and Michael P. Friedlander
%   $Id$

% ---------------------------------------------------------------

probList         = {};
solvers          = {};
fileList         = {};
supportedSolvers = {'gpsr','spgl1','l1ls','pdco'};

% Check parameters
if nargin < 1
  error('QPLSgen requires at least a problem ID');
end;

% Parse parameters
[opts,varg] = parseOptions(varargin,{},{'path','prefix','solvers'});
path        = getOption(opts,'path','data');
prefix      = getOption(opts,'prefix','QPLS');
solvers     = getOption(opts,'solvers',supportedSolvers);


% Make list of all recognized solvers
if ischar(solvers), solvers = {solvers}; end;
solvers = intersect(solvers, supportedSolvers);
if isempty(solvers), return; end;


% Convert problem number to name
if ~ischar(problem) && (length(problem) > 1)
     error('PARETOgen handles only one problem at a time');
end
if iscell(problem), problem = problem{1}; end;
problem = generateProblem(problem,'getname');
if isempty(problem), return; end;

% Get Pareto information to determine number of intervals
[probList,filename] = PARETOgen(problem);
nInterval = length(probList);

% Create problem and filename lists
idx = 1;
for i=1:length(solvers)
  % Set filename for collected results
  fileList{i} = sprintf('%s%s%s_%s_%s.mat', ...
                        path,filesep,prefix,problem,solvers{i});
  
  for j=1:nInterval
     fn = sprintf('%s%s%s_%s_%s_%03d.mat', ...
                  path,filesep,prefix,problem,solvers{i},j);
     entry = struct();
     entry.problem  = problem;
     entry.index    = j;
     entry.solver   = solvers{i};
     entry.filename = fn;
     probList{idx}  = entry;
     idx = idx + 1;
  end  
end
