function stats = TAUBPbatch(varargin)
%TAUBPbatch  Generate accuraty BP solutions
%
%   STATS = TAUBPBATCH(FLAGS,OPTIONS), all FLAGS and OPTIONS are
%   optional and have default values. All FLAGS are false unless 
%   set. Valid FLAGS are
%
%   'parallel'   - Take advantage of the parfor statement to speed
%                  up computations where possible
%   
%   OPTIONS consist of a keyword followed by a value:
%
%   'problems' - [TAUBPgen()] gives a list or cell array of all
%                problems to run  
%
%   The output variable STATS is a cell array of structures.
%   TAUBPbatch always checks if data for the problem is already
%   available on disk to avoid unnecessarily rerunning
%   experiments.
%
%   Examples:
%   s = TAUBPbatch('blocksig');  % Generate BP tau for blocksig
%
%Paper: Probing the Pareto Frontier for Basis Pursuit Solutions

%   Copyright 2008, Ewout van den Berg and Michael P. Friedlander
%   $Id$

% ---------------------------------------------------------------

% Parse parameters
[opts,varg] = parseOptions(varargin,{'parallel'},{'problems'});
probList    = getOption(opts,'problems',TAUBPgen(varg));

% Run problems
n = length(probList);
if opts.parallel
  stats = ParallelBatch(probList,@runprob);
else
  stats = {};
  for i=1:n
      p = probList{i};
      stats{i} = runprob(p);
  end
end

end % end TAUBPbatch

function stats = runprob(p)
    pID = p{1};
    fn  = p{2};

    if exist(fn,'file')
        s = load(fn,'stats');
        stats = s.stats;
    else
        s = generateProblem(pID);
        stats = TAUBPrun(s.A,s.b);
        save(fn,'p','stats');
    end
end
