function probList = TAUBPgen(varargin)
%TAUBPGEN  Generates list of TAUBP problems to run
%
%   PROBLIST = TAUBPGEN(OPTIONS), all OPTIONS are optional and
%   have default values. OPTIONS consist of a keyword followed by a
%   value:
%
%   'path'     - ['data'] directory to store results in
%   'prefix'   - ['TAUBP'] prefix of filename
%   'problems' - [all] list of Sparco problems
%
%   PROBLIST is a cell array of cells. The entries per problem are
%   {problem name, filename}.
%
%   Examples:
%   plist = TAUBPgen();              % Generate default list
%   plist = TAUBPgen('path','data'); % Store results in 'data' dir
%
%Paper: Probing the Pareto Frontier for Basis Pursuit Solutions

%   Copyright 2008, Ewout van den Berg and Michael P. Friedlander
%   $Id$

% ---------------------------------------------------------------

% Parse parameters
[opts,varg] = parseOptions(varargin,{},{'path','prefix','problems'});
path        = getOption(opts,'path','data');
prefix      = getOption(opts,'prefix','TAUBP');
problems    = getOption(opts,'problems',generateProblem('list'));

% Convert all problem numbers to names
names = {};
if ischar(problems), problems = {problems}; end;
if isnumeric(problems)
   for i=1:length(problems)
      names{i} = generateProblem(problems(i),'getname');
   end   
else
   for i=1:length(problems)
      names{i} = generateProblem(problems{i},'getname');
   end
end
names = unique(names);


probList = {}; idx = 1;
for i = 1:length(names)
    name = names{i}; if isempty(name), continue; end;
    fn = sprintf('%s%s%s_%s.mat',path,filesep,prefix,name);
    probList{idx} = {name,fn};
    idx = idx + 1;
end
