function sparcotable(exportflag)
%SPARCOTABLE  Generates list of Sparco problems
%
%   SPARCOTABLE(EXPORTFLAG) generates a table of Sparco problems
%   along with their statistics. When the EXPORTFLAG is set the
%   results are output to PDF file.
%
%Paper: Probing the Pareto Frontier for Basis Pursuit Solutions

%   Copyright 2008, Ewout van den Berg and Michael P. Friedlander
%   $Id$

% ---------------------------------------------------------------

% Get parameters
if nargin < 1, exportflag = 0; end;

list = generateProblem('list');
n = length(list);
for (i=1:n)
    id = list(i);
    P = generateProblem(id);
    name = P.info.name;
    m = P.sizeA(1);
    n = P.sizeA(2);
    bNorm = norm(P.b);
    
    row{i} = sprintf('\\\\ %-9s & %5i & %6i & %6i & %7.1e\n',name,id,m,n,bNorm);
end

row = sort(row); fid = 1;
if exportflag
   fid = fopen('./tables/sparcotable.tex','w');
end

for i = 1:length(list)
    fmt = row{i};
    fmt = strrep(fmt,'e+','\e+');
    fmt = strrep(fmt,'e-','\e-');
    fprintf(fid,'%s',fmt);
end

if fid > 1
   fclose(fid);
end
